@@ -1,5 +1,5 @@
 package Mail::DMARC;
-our $VERSION = '1.20190308'; # VERSION
+our $VERSION = '1.20190831'; # VERSION
 use strict;
 use warnings;
 
@@ -292,7 +292,7 @@ Mail::DMARC - Perl implementation of DMARC
 
 =head1 VERSION
 
-version 1.20190308
+version 1.20190831
 
 =head1 SYNOPSIS
 
@@ -616,7 +616,7 @@ Davide Migliavacca <shari@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Benny Pedersen ColocateUSA.net Jean Paul Galea Making GitHub Delicious. Marc Bradshaw Mohammad S Anwar Priyadi Iman Nurcahyo Ricardo Signes
+=for stopwords Benny Pedersen Jean Paul Galea Making GitHub Delicious. Marc Bradshaw Mohammad S Anwar Priyadi Iman Nurcahyo Ricardo Signes
 
 =over 4
 
@@ -626,10 +626,6 @@ Benny Pedersen <me@junc.eu>
 
 =item *
 
-ColocateUSA.net <company@colocateusa.net>
-
-=item *
-
 Jean Paul Galea <jeanpaul@yubico.com>
 
 =item *
@@ -642,10 +638,6 @@ Making GitHub Delicious. <iron@waffle.io>
 
 =item *
 
-Marc Bradshaw <marc_at_github@fastmail.com>
-
-=item *
-
 Marc Bradshaw <marc@marcbradshaw.net>
 
 =item *
